:orphan:

***********************
Preconfigured calendars
***********************

Russia
======

.. autoclass:: timeboard.calendars.RU.Weekly8x5


United Kingdom
==============

.. autoclass:: timeboard.calendars.UK.Weekly8x5


United States
=============

.. autoclass:: timeboard.calendars.US.Weekly8x5

